<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>AppMain</name>
    <message>
        <location filename="src/common/vlcpalyer.cpp" line="54"/>
        <location filename="src/main.cpp" line="94"/>
        <location filename="src/main.cpp" line="95"/>
        <location filename="src/views/vnotemainwindow.cpp" line="615"/>
        <source>Voice Notes</source>
        <translation>語音記事本</translation>
    </message>
    <message>
        <location filename="src/main.cpp" line="96"/>
        <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
        <translation>語音記事本是一款提供文本記事、語音錄音記錄的輕量級記事工具。</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="616"/>
        <source>Recordings not saved</source>
        <translation>錄音未保存</translation>
    </message>
</context>
<context>
    <name>DefaultName</name>
    <message>
        <location filename="src/db/vnotefolderoper.cpp" line="245"/>
        <source>Notebook</source>
        <translation>記事本</translation>
    </message>
    <message>
        <location filename="src/db/vnoteitemoper.cpp" line="228"/>
        <source>Text</source>
        <translation>文本</translation>
    </message>
    <message>
        <location filename="src/db/vnoteitemoper.cpp" line="243"/>
        <location filename="src/importolddata/olddbvisistors.cpp" line="154"/>
        <source>Voice</source>
        <translation>語音</translation>
    </message>
</context>
<context>
    <name>DetailPage</name>
    <message>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="213"/>
        <source>%1 notes selected</source>
        <translation>已選擇 %1 個筆記</translation>
    </message>
</context>
<context>
    <name>FolderSelectDialog</name>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="217"/>
        <source>Move Notes</source>
        <translation>移動筆記</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="244"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="245"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="src/views/homepage.cpp" line="48"/>
        <source>Create Notebook</source>
        <translation>新建記事本</translation>
    </message>
    <message>
        <location filename="src/views/homepage.cpp" line="60"/>
        <source>Create a notebook to start recording voice and making notes</source>
        <translation>新建一個記事本後，可以開始記錄語音及文字</translation>
    </message>
</context>
<context>
    <name>LeftView</name>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="380"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="394"/>
        <source>Move %1 notes (%2, ...) to:</source>
        <translation>移動 %2 等%1個筆記到：</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="381"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="384"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="392"/>
        <source>Move the note &quot;%1&quot; to:</source>
        <translation>移動 %1 筆記到：</translation>
    </message>
</context>
<context>
    <name>MiddleView</name>
    <message>
        <location filename="src/views/middleview.cpp" line="303"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="src/views/middleview.cpp" line="1057"/>
        <source>No search results</source>
        <translation>無搜索結果</translation>
    </message>
</context>
<context>
    <name>MiddleViewDelegate</name>
    <message>
        <location filename="src/views/middleviewdelegate.cpp" line="442"/>
        <source>Sticky Notes</source>
        <translation>已置頂</translation>
    </message>
</context>
<context>
    <name>NoteDetailContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="276"/>
        <source>Save as MP3</source>
        <translation>保存為MP3</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="277"/>
        <source>Voice to Text</source>
        <translation>語音轉文字</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="278"/>
        <location filename="src/common/actionmanager.cpp" line="305"/>
        <location filename="src/common/actionmanager.cpp" line="331"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="279"/>
        <location filename="src/common/actionmanager.cpp" line="306"/>
        <location filename="src/common/actionmanager.cpp" line="332"/>
        <source>Select all</source>
        <translation>全選</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="280"/>
        <location filename="src/common/actionmanager.cpp" line="307"/>
        <location filename="src/common/actionmanager.cpp" line="333"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="281"/>
        <location filename="src/common/actionmanager.cpp" line="308"/>
        <location filename="src/common/actionmanager.cpp" line="334"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="282"/>
        <location filename="src/common/actionmanager.cpp" line="309"/>
        <location filename="src/common/actionmanager.cpp" line="335"/>
        <source>Paste</source>
        <translation>黏貼</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="304"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="310"/>
        <source>Save as</source>
        <translation>另存為</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="336"/>
        <source>Text to Speech</source>
        <translation>語音朗讀</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="337"/>
        <source>Stop reading</source>
        <translation>停止朗讀</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="338"/>
        <source>Speech to Text</source>
        <translation>語音聽寫</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="339"/>
        <source>Translate</source>
        <translation>文本翻譯</translation>
    </message>
</context>
<context>
    <name>NotebookContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="220"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="221"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="222"/>
        <source>New note</source>
        <translation>新建筆記</translation>
    </message>
</context>
<context>
    <name>NotesContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="195"/>
        <source>Save as HTML</source>
        <translation>保存為HTML</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="196"/>
        <source>Save as TXT</source>
        <translation>保存為TXT</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="200"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="342"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="353"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="359"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="361"/>
        <source>Save note</source>
        <translation>保存筆記</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="240"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="242"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="336"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="345"/>
        <source>Move</source>
        <translation>移動</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="243"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="338"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="344"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="245"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="343"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="354"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="366"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="368"/>
        <source>Save voice recording</source>
        <translation>保存語音</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="246"/>
        <source>New note</source>
        <translation>新建筆記</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1258"/>
        <source>Unstick</source>
        <translation>取消置頂</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1260"/>
        <source>Sticky on Top</source>
        <translation>置頂</translation>
    </message>
</context>
<context>
    <name>Setting</name>
    <message>
        <location filename="src/common/setting.cpp" line="39"/>
        <source>Basic</source>
        <translation>基礎設置</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="40"/>
        <source>Audio Source</source>
        <translation>聲音來源</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="41"/>
        <source>Internal</source>
        <translation>系統聲音</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="42"/>
        <source>Microphone</source>
        <translation>麥克風聲音</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="919"/>
        <source>New notebook</source>
        <translation>新建記事本</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="920"/>
        <source>Rename notebook</source>
        <translation>重命名記事本</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="921"/>
        <source>Delete notebook</source>
        <translation>刪除記事本</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="943"/>
        <source>New note</source>
        <translation>新建筆記</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="944"/>
        <source>Rename note</source>
        <translation>重命名筆記</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="945"/>
        <source>Delete note</source>
        <translation>刪除筆記</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="946"/>
        <source>Play/Pause</source>
        <translation>播放/暫停</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="947"/>
        <source>Record voice</source>
        <translation>錄音</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="948"/>
        <source>Save note</source>
        <translation>保存筆記</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="949"/>
        <source>Save recordings</source>
        <translation>保存語音</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="969"/>
        <source>Select all</source>
        <translation>全選</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="970"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="971"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="972"/>
        <source>Paste</source>
        <translation>黏貼</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="973"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="996"/>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="997"/>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
</context>
<context>
    <name>ShortcutsGroups</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="925"/>
        <source>Notebooks</source>
        <translation>記事本</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="953"/>
        <source>Notes</source>
        <translation>筆記</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="977"/>
        <source>Edit</source>
        <translation>編輯</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1001"/>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
</context>
<context>
    <name>SplashView</name>
    <message>
        <location filename="src/views/splashview.cpp" line="46"/>
        <source>Loading...</source>
        <translation>正在加載...</translation>
    </message>
</context>
<context>
    <name>TitleBar</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="371"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1889"/>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1890"/>
        <source>Privacy Policy</source>
        <translation>私隱政策</translation>
    </message>
</context>
<context>
    <name>UpgradeView</name>
    <message>
        <location filename="src/importolddata/upgradeview.cpp" line="50"/>
        <source>Importing notes from the old version, please wait...</source>
        <translation>因產品升級正在導入數據，請稍候...</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="src/common/utils.cpp" line="56"/>
        <source>1 min ago</source>
        <translation>1分鐘前</translation>
    </message>
    <message>
        <location filename="src/common/utils.cpp" line="58"/>
        <source>%1 mins ago</source>
        <translation>%1分鐘前</translation>
    </message>
    <message>
        <location filename="src/common/utils.cpp" line="64"/>
        <source>Yesterday</source>
        <translation>昨天</translation>
    </message>
</context>
<context>
    <name>VNoteErrorMessage</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="881"/>
        <source>The voice conversion failed due to the poor network connection, please have a check</source>
        <translation>當前網絡狀態差，語音轉寫失敗，請確保網絡暢通</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="885"/>
        <source>Voice to text conversion failed</source>
        <translation>語音轉文字失敗</translation>
    </message>
</context>
<context>
    <name>VNoteMainWindow</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="470"/>
        <source>Create Notebook</source>
        <translation>新建記事本</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialog</name>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="53"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="132"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="133"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="136"/>
        <source>Are you sure you want to delete this notebook?
All notes in it will be deleted</source>
        <translation>您確定要刪除這個記事本嗎？
包含的所有筆記將被刪除</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="139"/>
        <source>Do you want to stop the current recording?</source>
        <translation>當前錄音中，是否停止錄音？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="143"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation>您確定要刪除選中的%1條筆記嗎？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="145"/>
        <source>Are you sure you want to delete this note?</source>
        <translation>您確定要刪除這條筆記嗎？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="149"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation>無法轉寫此條語音筆記，暫僅支持20分鐘內的語音筆記。</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="153"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation>當前有語音筆記正在轉寫中，是否確定關閉？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="156"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation>當前系統輸入音量低，可能影響錄音效果。是否繼續錄音？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="159"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation>語音筆記以及轉寫文字剪切後不能黏貼，是否繼續？</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="162"/>
        <source>Save failed</source>
        <translation>保存失敗</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="166"/>
        <source>You do not have permission to save files there</source>
        <translation>您沒有權限在此位置保存這類文件</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="170"/>
        <source>The voice note has been deleted</source>
        <translation>該語音筆記已被刪除</translation>
    </message>
</context>
<context>
    <name>VNoteRecordBar</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1736"/>
        <source>Your audio recording device does not work.</source>
        <translation>您的錄音設備異常，無法錄製語音。</translation>
    </message>
    <message>
        <location filename="src/views/vnoterecordbar.cpp" line="249"/>
        <source>No recording device detected</source>
        <translation>未檢測到錄音設備</translation>
    </message>
</context>
<context>
    <name>VoiceNoteItem</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1679"/>
        <source>Converting voice to text</source>
        <translation>正在轉為文字...</translation>
    </message>
</context>
<context>
    <name>web</name>
    <message>
        <location filename="src/common/jscontent.cpp" line="141"/>
        <source>Font</source>
        <translation>字體</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="142"/>
        <source>Font size</source>
        <translation>字號</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="143"/>
        <source>Font color</source>
        <translation>字體顏色</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="144"/>
        <source>Text highlight color</source>
        <translation>背景色</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="145"/>
        <source>Bold</source>
        <translation>加粗</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="146"/>
        <source>Italic</source>
        <translation>斜體</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="147"/>
        <source>Underline</source>
        <translation>下劃線</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="148"/>
        <source>Strikethrough</source>
        <translation>刪除線</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="149"/>
        <source>Bullets</source>
        <translation>無序列表</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="150"/>
        <source>Numbering</source>
        <translation>有序列表</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="151"/>
        <source>More colors</source>
        <translation>更多顏色</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="152"/>
        <source>Recent</source>
        <translation>最近使用</translation>
    </message>
</context>
</TS>